<?php

/**
 * @file
 * Admin page callbacks for the Sell links module.
 */

/**
 * Form builder; Configure Sell links settings.
 *
 * @ingroup forms
 *
 * @see system_settings_form()
 */
function link_partners_admin_settings_form($form, $form_state) {
  $form = [];

  $form['linkfeed']['l_checkbox'] = [
    '#type' => 'checkbox',
    '#title' => t('Linkfeed'),
    '#description' => t('Check this checkbox for show links with !partner', ['!partner' => 'Linkfeed']),
    '#default_value' => variable_get('link_partners_linkfeed_status'),
  ];

  $form['trustlink']['t_checkbox'] = [
    '#type' => 'checkbox',
    '#title' => t('TrustLink'),
    '#description' => t('Check this checkbox for show links with !partner', ['!partner' => 'Trustlink']),
    '#default_value' => variable_get('link_partners_trustlink_status'),
  ];

  $form['sape']['s_checkbox'] = [
    '#type' => 'checkbox',
    '#title' => t('Sape'),
    '#description' => t('Check this checkbox for show links with !partner', ['!partner' => 'Sape']),
    '#default_value' => variable_get('link_partners_sape_status'),
  ];

  $form['mainlink']['m_checkbox'] = [
    '#type' => 'checkbox',
    '#title' => t('Mainlink'),
    '#description' => t('Check this checkbox for show links with !partner', ['!partner' => 'Mainlink']),
    '#default_value' => variable_get('link_partners_mainlink_status'),
  ];

  $form['submit'] = [
    '#type' => 'submit',
    '#value' => t('Submit'),
    '#submit' => ['link_partners_admin_settings_form_submit'],
    '#validate' => ['link_partners_admin_settings_form_validate'],
    '#weight' => 20,
  ];

  return $form;
}

/**
 * Callback submit function.
 *
 * @see link_partners_admin_settings_form()
 */
function link_partners_admin_settings_form_submit($form, &$form_state) {

  switch ($form_state['values']['l_checkbox']) {
    case 0:
      variable_del('link_partners_linkfeed_quantity_blocks');
    case 1:
      variable_set('link_partners_linkfeed_status', $form_state['values']['l_checkbox']);
      break;
  }

  switch ($form_state['values']['t_checkbox']) {
    case 0:
      variable_del('link_partners_trustlink_quantity_blocks');
    case 1:
      variable_set('link_partners_trustlink_status', $form_state['values']['t_checkbox']);
      break;
  }

  switch ($form_state['values']['s_checkbox']) {
    case 0:
      variable_del('link_partners_sape_quantity_blocks');
    case 1:
      variable_set('link_partners_sape_status', $form_state['values']['s_checkbox']);
      break;
  }

  switch ($form_state['values']['m_checkbox']) {
    case 0:
      variable_del('link_partners_mainlink_quantity_blocks');
    case 1:
      variable_set('link_partners_mainlink_status', $form_state['values']['m_checkbox']);
      break;
  }

  // Rebuild menu items.
  menu_rebuild();
}

/**
 * Callback validation function.
 *
 * @see link_partners_admin_settings_form()
 */
function link_partners_admin_settings_form_validate($form, &$form_state) {
  if (empty($form_state['values']['filename'])) {
    // form_set_error('filename', t('Please input an aggregate filename.'));,
    // $form_state['values']['error'] = TRUE;.
  }

  drupal_set_message(t('Configuration success saved'));
}

/**
 * Delete cache link file.
 *
 * @param string $partner
 *   This is name partner (sape, linkfeed etc.).
 *
 * @see link_partners_menu()
 */
function link_partners_refresh($partner) {

  switch ($partner) {

    case 'linkfeed':
      $id = LINK_PARTNERS_CONFIG_LINKFEED_USER;
      $file_cache = drupal_realpath('public://link_partners/' . $partner . '/' . $id . '/linkfeed.links.db');
      break;

    case 'trustlink':
      $id = LINK_PARTNERS_CONFIG_TRUSTLINK_USER;
      $file_cache = drupal_realpath('public://link_partners/' . $partner . '/' . $id . '/trustlink.links.db');
      break;

    case 'sape':
      $id = LINK_PARTNERS_CONFIG_SAPE_USER;
      $file_cache = drupal_realpath('public://link_partners/' . $partner . '/' . $id . '/links.db');
      break;

    case 'mainlink':
      $id = LINK_PARTNERS_CONFIG_MAINLINK_USER;
      $file_cache = drupal_realpath('public://link_partners/' . $partner . '/' . $id . '/data/*');
      // An array with all file names.
      $file_cache = glob($file_cache);

      break;
  }

  // Check and delete file cache.
  if (is_array($file_cache)) {

    // Delete all file cache.
    foreach ($file_cache as $file) {

      if (file_exists($file)) {

        unlink($file);
      }
    }
  }
  elseif (file_exists($file_cache)) {

    unlink($file_cache);
  }

  drupal_set_message(t('File cache has been refreshed'));
  drupal_goto('/admin/config/services/link-partners/' . $partner);
}

/**
 * Form builder; Configure Sell links settings.
 *
 * @ingroup forms
 *
 * @see system_settings_form()
 */
function link_partners_linkfeed_settings_form($form, $form_state) {
  $form = [];

  $path = [
    'file' => drupal_realpath('public://link_partners/linkfeed/' . LINK_PARTNERS_CONFIG_LINKFEED_USER . '/linkfeed.php'),
    'directory' => drupal_realpath('public://link_partners/linkfeed/' . LINK_PARTNERS_CONFIG_LINKFEED_USER),
  ];

  $form['linkfeed'] = [
    '#type' => 'fieldset',
    '#title' => t('@partner settings', [
      '@partner' => 'Linkfeed',
    ]),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  ];

  $id = variable_get('link_partners_linkfeed_id');
  $form['linkfeed']['ID'] = [
    '#type' => 'textfield',
    '#title' => t('ID'),
    '#description' => t('This is ID you have get on site <a href="@link" target="_blank">@partner</a> (example, bla3bla2bla1bla6blabla3bla2bla1).', [
      '@link' => 'http://www.linkfeed.ru/platforms/new',
      '@partner' => 'Linkfeed',
    ]),
    '#default_value' => $id,
    '#size' => 60,
    '#maxlength' => 100,
  ];

  // Check file script.
  if (file_exists($path['file'])) {

    require_once $path['file'];

    // Check class in file.
    if (class_exists('LinkfeedClient')) {

      $linkfeed = new LinkfeedClient();

      $form['linkfeed']['script_exists'] = [
        '#type' => 'item',
        '#title' => t('Script found'),
        '#markup' => t('The script found and its version: <strong>@version</strong>. Update script may on <a href="@link" target="_blank">@partner</a>', [
          '@version' => $linkfeed->lc_version ,
          '@link' => 'http://www.linkfeed.ru/platforms/new',
          '@partner' => 'Linkfeed',
        ]),
      ];

      $form['linkfeed']['number_blocks'] = [
        '#type' => 'select',
        '#title' => t('The number of blocks'),
        '#options' => [
          1 => 1,
          2 => 2,
          3 => 3,
          4 => 4,
          5 => 5,
        ],
        '#default_value' => variable_get('link_partners_linkfeed_quantity_blocks', 1),
        '#description' => t('Set the desired number of blocks that you need.'),
      ];

      $quantity_block = variable_get('link_partners_linkfeed_quantity_blocks');
      if (empty($quantity_block)) {
        // Set default value quantity blocks.
        variable_set('link_partners_linkfeed_quantity_blocks', 1);
      }

      $form['linkfeed']['links_block'] = [
        '#type' => 'select',
        '#title' => t('Number links of block'),
        '#options' => [
          1 => 1,
          2 => 2,
          3 => 3,
        ],
        '#default_value' => variable_get('link_partners_linkfeed_links_block', 3),
        '#description' => t('Set the desired number link of one block. Default value is: 3 links on block. Also check your configuration on @partner.', [
          '@partner' => 'Linkfeed',
        ]),
      ];

      if (file_exists($path['directory'] . '/linkfeed.links.db')) {

        $form['linkfeed']['script_exists'] = [
          '#type' => 'item',
          '#title' => t('Size cache file'),
          '#markup' => t('File size <strong>@partner.links.db</strong>: @size Kb. <a href="@refresh">Refresh file</a>', [
            '@refresh' => '/linkfeed/refresh',
            '@size' => filesize($path['directory'] . '/linkfeed.links.db'),
            '@partner' => 'linkfeed',
          ]),
        ];
      }

    }
    else {

      $form['linkfeed']['script_exists'] = [
        '#type' => 'item',
        '#title' => t('Script @partner.php not valid', [
          '@partner' => 'linkfeed',
        ]),
        '#markup' => t('File script in folder <strong>@file</strong> not valid. Please, reload archive with script on <a href="@link" target="_blank">@partner</a>', [
          '@file' => $path['file'],
          '@link' => 'http://www.linkfeed.ru/platforms/new',
          '@partner' => 'Linkfeed',
        ]),
      ];
    }
  }
  else {

    $form['linkfeed']['script_exists'] = [
      '#type' => 'item',
      '#title' => t('Script not found'),
      '#markup' => t('Please copy script in folder "<strong>@directory</strong>". The script may download on <a href="@link" target="_blank">@partner</a>', [
        '@directory' => $path['directory'],
        '@link' => 'http://www.linkfeed.ru/platforms/new',
        '@partner' => 'Linkfeed',
      ]),
    ];
  }

  if (empty($id)) {
    // Hide field 'script_exists' when ID undifinded.
    $form['linkfeed']['script_exists'] = NULL;
  }

  $form['submit'] = [
    '#type' => 'submit',
    '#value' => t('Submit'),
    '#submit' => ['link_partners_linkfeed_settings_form_submit'],
    '#validate' => ['link_partners_linkfeed_settings_form_validate'],
    '#weight' => 20,
  ];

  return $form;
}

/**
 * Callback submit function.
 *
 * @see link_partners_linkfeed_settings_form()
 */
function link_partners_linkfeed_settings_form_submit($form, &$form_state) {

  if (!empty($form_state['values']['ID'])) {
    variable_set('link_partners_linkfeed_id', $form_state['values']['ID']);
  }
  else {
    variable_del('link_partners_linkfeed_id');
  }

  if (!empty($form_state['values']['number_blocks'])) {
    variable_set('link_partners_linkfeed_quantity_blocks', $form_state['values']['number_blocks']);
    // Clear cache.
    drupal_flush_all_caches();
  }

  if (!empty($form_state['values']['links_block'])) {
    variable_set('link_partners_linkfeed_links_block', $form_state['values']['links_block']);
  }
}

/**
 * Callback validation function.
 *
 * @see link_partners_linkfeed_settings_form()
 */
function link_partners_linkfeed_settings_form_validate($form, &$form_state) {
  drupal_set_message(t('Configuration success saved'));
}

/**
 * Form builder; Configure Trustlink settings.
 *
 * @ingroup forms
 *
 * @see system_settings_form()
 */
function link_partners_trustlink_settings_form($form, $form_state) {
  $form = [];

  $path = [
    'file' => drupal_realpath('public://link_partners/trustlink/' . LINK_PARTNERS_CONFIG_TRUSTLINK_USER . '/trustlink.php'),
    'directory' => drupal_realpath('public://link_partners/trustlink/' . LINK_PARTNERS_CONFIG_TRUSTLINK_USER),
  ];

  $form['trustlink'] = [
    '#type' => 'fieldset',
    '#title' => t('@partner settings', [
      '@partner' => 'TrushLink',
    ]),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  ];

  $id = variable_get('link_partners_trustlink_id');
  $form['trustlink']['ID'] = [
    '#type' => 'textfield',
    '#title' => t('ID'),
    '#description' => t('This is ID you have get on site <a href="@link" target="_blank">@partner</a> (example, bla3bla2bla1bla6blabla3bla2bla1).', [
      '@link' => 'http://www.trustlink.ru/sites/new',
      '@partner' => 'TrustLink',
    ]),
    '#default_value' => variable_get('link_partners_trustlink_id'),
    '#size' => 60,
    '#maxlength' => 100,
  ];

  // Check file script.
  if (file_exists($path['file'])) {

    require_once $path['file'];

    // Check class in file.
    if (class_exists('TrustlinkClient')) {

      $trustlink = new TrustlinkClient();

      $form['trustlink']['script_exists'] = [
        '#type' => 'item',
        '#title' => t('Script found'),
        '#markup' => t('The script found and its version: <strong>@version</strong>. Update script may on <a href="@link" target="_blank">@partner</a>', [
          '@version' => $trustlink->tl_version,
          '@link' => 'http://www.trustlink.ru/sites/new',
          '@partner' => 'Trustlink',
        ]),
      ];

      $form['trustlink']['number_blocks'] = [
        '#type' => 'select',
        '#title' => t('The number of blocks'),
        '#options' => [
          1 => 1,
          2 => 2,
          3 => 3,
          4 => 4,
          5 => 5,
        ],
        '#default_value' => variable_get('link_partners_trustlink_quantity_blocks', 1),
        '#description' => t('Set the desired number of blocks that you need.'),
      ];

      $quantity_block = variable_get('link_partners_trustlink_quantity_blocks');
      if (empty($quantity_block)) {
        // Set default value quantity blocks.
        variable_set('link_partners_trustlink_quantity_blocks', 1);
      }

      $form['trustlink']['links_block'] = [
        '#type' => 'select',
        '#title' => t('Number links of block'),
        '#options' => [
          1 => 1,
          2 => 2,
          3 => 3,
        ],
        '#default_value' => variable_get('link_partners_trustlink_links_block', 3),
        '#description' => t('Set the desired number link of one block. Default value is: 3 links on block. Also check your configuration on @partner.', [
          '@partner' => 'TrustLink',
        ]),

      ];

      if (file_exists($path['directory'] . '/trustlink.links.db')) {

        $form['trustlink']['script_exists'] = [
          '#type' => 'item',
          '#title' => t('Size cache file'),
          '#markup' => t('File size <strong>@partner.links.db</strong>: @size Kb. <a href="@refresh">Refresh file</a>', [
            '@refresh' => '/trustlink/refresh',
            '@size' => filesize($path['directory'] . '/trustlink.links.db'),
            '@partner' => 'trustlink',
          ]),
        ];
      }

    }
    else {

      $form['trustlink']['script_exists'] = [
        '#type' => 'item',
        '#title' => t('Script @partner.php not valid', [
          '@partner' => 'trustlink',
        ]),
        '#markup' => t('File script in folder <strong>@file</strong> not valid. Please, reload archive with script on <a href="@link" target="_blank">@partner</a>', [
          '@file' => $path['file'],
          '@link' => 'http://www.trustlink.ru/sites/new',
          '@partner' => 'TrushLink',
        ]),
      ];
    }
  }
  else {

    $form['trustlink']['script_exists'] = [
      '#type' => 'item',
      '#title' => t('Script not found'),
      '#markup' => t('Please copy script in folder "<strong>@directory</strong>". The script may download on <a href="@link" target="_blank">@partner</a>', [
        '@directory' => $path['directory'],
        '@link' => 'http://www.trustlink.ru/sites/new',
        '@partner' => 'TrustLink',
      ]),
    ];
  }

  if (empty($id)) {
    // Hide field 'script_exists' when ID undifinded.
    $form['trustlink']['script_exists'] = NULL;
  }

  $form['submit'] = [
    '#type' => 'submit',
    '#value' => t('Submit'),
    '#submit' => ['link_partners_trustlink_settings_form_submit'],
    '#validate' => ['link_partners_trustlink_settings_form_validate'],
    '#weight' => 20,
  ];

  return $form;
}

/**
 * Callback submit function.
 *
 * @see link_partners_trustlink_settings_form()
 */
function link_partners_trustlink_settings_form_submit($form, &$form_state) {

  if (!empty($form_state['values']['ID'])) {
    variable_set('link_partners_trustlink_id', $form_state['values']['ID']);
  }
  else {
    variable_del('link_partners_trustlink_id');
  }

  if (!empty($form_state['values']['number_blocks'])) {
    variable_set('link_partners_trustlink_quantity_blocks', $form_state['values']['number_blocks']);
    // Clear cache.
    drupal_flush_all_caches();
  }

  if (!empty($form_state['values']['links_block'])) {
    variable_set('link_partners_trustlink_links_block', $form_state['values']['links_block']);
  }
}

/**
 * Callback validation function.
 *
 * @see link_partners_trustlink_settings_form()
 */
function link_partners_trustlink_settings_form_validate($form, &$form_state) {
  drupal_set_message(t('Configuration success saved'));
}

/**
 * Form builder; Configure Sape settings.
 *
 * @ingroup forms
 *
 * @see system_settings_form()
 */
function link_partners_sape_settings_form($form, $form_state) {
  $form = [];

  $path = [
    'file' => drupal_realpath('public://link_partners/sape/' . LINK_PARTNERS_CONFIG_SAPE_USER . '/sape.php'),
    'directory' => drupal_realpath('public://link_partners/sape/' . LINK_PARTNERS_CONFIG_SAPE_USER),
  ];

  $form['sape'] = [
    '#type' => 'fieldset',
    '#title' => t('@partner settings', [
      '@partner' => 'Sape',
    ]),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  ];

  $id = variable_get('link_partners_sape_id');
  $form['sape']['ID'] = [
    '#type' => 'textfield',
    '#title' => t('ID'),
    '#description' => t('This is ID you have get on site <a href="@link" target="_blank">@partner</a> (example, bla3bla2bla1bla6blabla3bla2bla1).', [
      '@link' => 'https://www.sape.ru/site.php?act=add',
      '@partner' => 'Sape',
    ]),
    '#default_value' => variable_get('link_partners_sape_id'),
    '#size' => 60,
    '#maxlength' => 100,
    '#weight' => -10,
  ];

  // Check file script.
  if (file_exists($path['file'])) {

    require_once $path['file'];

    // Check class in file.
    if (class_exists('SAPE_base')) {

      $form['sape']['script_exists'] = [
        '#type' => 'item',
        '#title' => t('Script found'),
        '#markup' => t('The script found. Update script may on <a href="@link" target="_blank">@partner</a>', [
          '@link' => 'http://www.mainlink.ru/xmy/web/xscript/start.aspx?id=87',
          '@partner' => 'Sape',
        ]),
      ];

      $form['sape']['number_blocks'] = [
        '#type' => 'select',
        '#title' => t('The number of blocks'),
        '#options' => [
          1 => 1,
          2 => 2,
          3 => 3,
          4 => 4,
          5 => 5,
        ],
        '#default_value' => variable_get('link_partners_sape_quantity_blocks', 1),
        '#description' => t('Set the desired number of blocks that you need.'),
      ];

      $quantity_block = variable_get('link_partners_sape_quantity_blocks');
      if (empty($quantity_block)) {
        // Set default value quantity blocks.
        variable_set('link_partners_sape_quantity_blocks', 1);
      }

      $form['sape']['links_block'] = [
        '#type' => 'select',
        '#title' => t('Number links of block'),
        '#options' => [
          1 => 1,
          2 => 2,
          3 => 3,
        ],
        '#default_value' => variable_get('link_partners_sape_links_block', 3),
        '#description' => t('Set the desired number link of one block. Default value is: 3 links on block. Also check your configuration on @partner.', [
          '@partner' => 'Sape',
        ]),
      ];

      $form['sape']['context'] = [
        '#type' => 'checkbox',
        '#title' => t('Enable context links'),
        '#description' => t('Go to the edit content type page and move to "Manage display" and select the <strong>Context</strong> format. After that, contextual links will be sold from this field.'),
        '#default_value' => variable_get('link_partners_sape_context_status', 0),
        '#weight' => -1,
      ];

      if (file_exists($path['directory'] . '/links.db')) {

        $form['sape']['script_exists'] = [
          '#type' => 'item',
          '#title' => t('Size cache file'),
          '#markup' => t('File size <strong>links.db</strong>: @size Kb. <a href="@refresh">Refresh file</a>', [
            '@refresh' => '/sape/refresh',
            '@size' => filesize($path['directory'] . '/links.db'),
          ]),
        ];
      }

    }
    else {

      $form['sape']['script_exists'] = [
        '#type' => 'item',
        '#title' => t('Script @partner.php not valid', [
          '@partner' => 'sape',
        ]),
        '#markup' => t('File script in folder <strong>@file</strong> not valid. Please, reload archive with script on <a href="@link" target="_blank">@partner</a>', [
          '@file' => $path['file'],
          '@link' => 'https://www.sape.ru/site.php?act=add',
          '@partner' => 'TrushLink',
        ]),
      ];
    }
  }
  else {

    $form['sape']['script_exists'] = [
      '#type' => 'item',
      '#title' => t('Script not found'),
      '#markup' => t('Please copy script in folder "<strong>@directory</strong>". The script may download on <a href="@link" target="_blank">@partner</a>', [
        '@directory' => $path['directory'],
        '@link' => 'https://www.sape.ru/site.php?act=add',
        '@partner' => 'Sape',
      ]),
    ];
  }

  if (empty($id)) {
    // Hide field 'script_exists' when ID undifinded.
    $form['sape']['script_exists'] = NULL;
  }

  $form['submit'] = [
    '#type' => 'submit',
    '#value' => t('Submit'),
    '#submit' => ['link_partners_sape_settings_form_submit'],
    '#validate' => ['link_partners_sape_settings_form_validate'],
    '#weight' => 20,
  ];

  return $form;
}

/**
 * Callback submit function.
 *
 * @see link_partners_sape_settings_form()
 */
function link_partners_sape_settings_form_submit($form, &$form_state) {

  if (!empty($form_state['values']['ID'])) {
    variable_set('link_partners_sape_id', $form_state['values']['ID']);
  }
  else {
    variable_del('link_partners_sape_id');
  }

  if (!empty($form_state['values']['number_blocks'])) {
    variable_set('link_partners_sape_quantity_blocks', $form_state['values']['number_blocks']);
    // Clear cache.
    drupal_flush_all_caches();
  }

  if (!empty($form_state['values']['links_block'])) {
    variable_set('link_partners_sape_links_block', $form_state['values']['links_block']);
  }

  variable_set('link_partners_sape_context_status', $form_state['values']['context']);

}

/**
 * Callback validation function.
 *
 * @see link_partners_sape_settings_form()
 */
function link_partners_sape_settings_form_validate($form, &$form_state) {
  drupal_set_message(t('Configuration success saved'));
}

/**
 * Form builder; Configure Mainlink settings.
 *
 * @ingroup forms
 *
 * @see system_settings_form()
 */
function link_partners_mainlink_settings_form($form, $form_state) {
  $form = [];

  $path = [
    'file' => drupal_realpath('public://link_partners/mainlink/' . LINK_PARTNERS_CONFIG_MAINLINK_USER . '/mainlink.php'),
    'directory' => drupal_realpath('public://link_partners/mainlink/' . LINK_PARTNERS_CONFIG_MAINLINK_USER),
  ];

  $form['mainlink'] = [
    '#type' => 'fieldset',
    '#title' => t('@partner settings', [
      '@partner' => 'MainLink',
    ]),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  ];

  $id = variable_get('link_partners_mainlink_id');
  $form['mainlink']['ID'] = [
    '#type' => 'textfield',
    '#title' => t('ID'),
    '#description' => t('This is ID you have get on site <a href="@link" target="_blank">@partner</a> (example, bla3bla2bla1bla6blabla3bla2bla1).', [
      '@link' => 'http://www.mainlink.ru/xmy/web/xscript/start.aspx?id=87',
      '@partner' => 'MainLink',
    ]),
    '#default_value' => variable_get('link_partners_mainlink_id'),
    '#size' => 60,
    '#maxlength' => 100,
  ];

  // Check file script.
  if (file_exists($path['file'])) {

    require_once $path['file'];

    // Check class in file.
    if (class_exists('MLClient')) {

      $form['mainlink']['script_exists'] = [
        '#type' => 'item',
        '#title' => t('Script found'),
        '#markup' => t('The script found. Update script may on <a href="@link" target="_blank">@partner</a>', [
          '@link' => 'http://www.mainlink.ru/xmy/web/xscript/start.aspx?id=87',
          '@partner' => 'MainLink',
        ]),
      ];

      $form['mainlink']['number_blocks'] = [
        '#type' => 'select',
        '#title' => t('The number of blocks'),
        '#options' => [
          1 => 1,
          2 => 2,
          3 => 3,
          4 => 4,
          5 => 5,
        ],
        '#default_value' => variable_get('link_partners_mainlink_quantity_blocks', 1),
        '#description' => t('Set the desired number of blocks that you need.'),
      ];

      $quantity_block = variable_get('link_partners_mainlink_quantity_blocks');
      if (empty($quantity_block)) {
        // Set default value quantity blocks.
        variable_set('link_partners_mainlink_quantity_blocks', 1);
      }

      $form['mainlink']['links_block'] = [
        '#type' => 'select',
        '#title' => t('Number links of block'),
        '#options' => [
          1 => 1,
          2 => 2,
          3 => 3,
        ],
        '#default_value' => variable_get('link_partners_mainlink_links_block', 3),
        '#description' => t('Set the desired number link of one block. Default value is: 3 links on block. Also check your configuration on @partner.', [
          '@partner' => 'MainLink',
        ]),
      ];

      if (file_exists($path['directory'] . '/mainlink.links.db')) {

        $form['mainlink']['script_exists'] = [
          '#type' => 'item',
          '#title' => t('Size cache file'),
          '#markup' => t('File size <strong>@partner.links.db</strong>: @size Kb. <a href="@refresh">Refresh file</a>', [
            '@refresh' => '/mainlink/refresh',
            '@size' => filesize($path['directory'] . '/mainlink.links.db'),
            '@partner' => 'mainlink',
          ]),
        ];
      }

    }
    else {

      $form['mainlink']['script_exists'] = [
        '#type' => 'item',
        '#title' => t('Script @partner.php not valid', [
          '@partner' => 'mainlink',
        ]),
        '#markup' => t('File script in folder <strong>@file</strong> not valid. Please, reload archive with script on <a href="@link" target="_blank">@partner</a>', [
          '@file' => $path['file'],
          '@link' => 'http://www.mainlink.ru/xmy/web/xscript/start.aspx?id=87',
          '@partner' => 'MainLink',
        ]),
      ];
    }
  }
  else {

    $form['mainlink']['script_exists'] = [
      '#type' => 'item',
      '#title' => t('Script not found'),
      '#markup' => t('Please copy script in folder "<strong>@directory</strong>". The script may download on <a href="@link" target="_blank">@partner</a>', [
        '@directory' => $path['directory'],
        '@link' => 'http://www.mainlink.ru/xmy/web/xscript/start.aspx?id=87',
        '@partner' => 'MainLink',
      ]),
    ];
  }

  if (empty($id)) {
    // Hide field 'script_exists' when ID undifinded.
    $form['mainlink']['script_exists'] = NULL;
  }

  $form['submit'] = [
    '#type' => 'submit',
    '#value' => t('Submit'),
    '#submit' => ['link_partners_mainlink_settings_form_submit'],
    '#validate' => ['link_partners_mainlink_settings_form_validate'],
    '#weight' => 20,
  ];

  return $form;
}

/**
 * Callback submit function.
 *
 * @see link_partners_mainlink_settings_form()
 */
function link_partners_mainlink_settings_form_submit($form, &$form_state) {

  if (!empty($form_state['values']['ID'])) {
    variable_set('link_partners_mainlink_id', $form_state['values']['ID']);
  }
  else {
    variable_del('link_partners_mainlink_id');
  }

  if (!empty($form_state['values']['number_blocks'])) {
    variable_set('link_partners_mainlink_quantity_blocks', $form_state['values']['number_blocks']);
    // Clear cache.
    drupal_flush_all_caches();
  }

  if (!empty($form_state['values']['links_block'])) {
    variable_set('link_partners_mainlink_links_block', $form_state['values']['links_block']);
  }
}

/**
 * Callback validation function.
 *
 * @see link_partners_mainlink_settings_form()
 */
function link_partners_mainlink_settings_form_validate($form, &$form_state) {
  drupal_set_message(t('Configuration success saved'));
}
